@@ -257,6 +257,12 @@ class Loader:
 
         TypeError is raised if there is no known way to treat type_,
         otherwise all errors raise a ValueError.
+
+        annotation is used by recursive calls to track which path was
+        being executed in case of exceptions.
+
+        It is only needed when calling load recursively from
+        a custom handler.
         """
         p_index = self._indexcache.get(type_)
 
@@ -484,9 +490,12 @@ def _namedtupleload(l: Loader, value: Dict[str, Any], type_) -> Any:
         except ValueError as e:
             raise TypedloadValueError(str(e), value=value, type_=type_)
 
-    if getattr(type_, '__total__', True) == False:
-        # For TypedDict, total=False means that fields can be safely skipped
-        # So we set the necessary_fields to empty.
+    if hasattr(type_, '__required_keys__') and hasattr(type_, '__optional_keys__'):
+        # TypedDict, since 3.9
+        necessary_fields = type_.__required_keys__
+        optional_fields = type_.__optional_keys__
+    elif getattr(type_, '__total__', True) == False:
+        # TypedDict, only for 3.8
         necessary_fields = set()
     else:
         necessary_fields = fields.difference(optional_fields)
@@ -602,8 +611,13 @@ def _enumload(l: Loader, value, type_) -> Enum:
             return type_(l.load(value, t, annotation=Annotation(AnnotationType.UNION, t)))
         except Exception as e:
             exceptions.append(e)
+    if len(type_.__members__) <= 10 and all(type(i.value) in l.basictypes for i in type_.__members__.values()):
+        lst = '\nValue %s not between: ' % repr(value) + \
+        ', '.join(repr(i.value) for i in type_.__members__.values())
+    else:
+        lst = ''
     raise TypedloadValueError(
-        'Value of %s could not be loaded into %s' % (tname(type(value)), tname(type_)),
+        'Value of %s could not be loaded into %s%s' % (tname(type(value)), tname(type_), lst),
         value=value,
         type_=type_,
         exceptions=exceptions
